==> cppad_2014.00.00.3.orig.tar.gz: cppad-20140000.3/doc/_link_sparse_jacobian_xml.js <==
var list_across0 = [
'_contents_xml.htm',
'_reference.xml',
'_index.xml',
'_search_xml.htm',
'_external.xml'
];
var list_up0 = [
'cppad.xml',
'speed.xml',
'speed_main.xml',
'link_sparse_jacobian.xml'
];
var list_down3 = [
'install.xml',
'introduction.xml',
'ad.xml',
'adfun.xml',
'preprocessor.xml',
'multi_thread.xml',
'library.xml',
'ipopt_solve.xml',
'example.xml',
'speed.xml',
'appendix.xml'
];
var list_down2 = [
'speed_main.xml',
'speed_utility.xml',
'speed_double.xml',
'speed_adolc.xml',
'speed_cppad.xml',
'speed_fadbad.xml',
'speed_sacado.xml'
];
var list_down1 = [
'link_det_lu.xml',
'link_det_minor.xml',
'link_mat_mul.xml',
'link_ode.xml',
'link_poly.xml',
'link_sparse_hessian.xml',
'link_sparse_jacobian.xml',
'microsoft_timer.xml'
];
var list_current0 = [
'link_sparse_jacobian.xml#Prototype',
'link_sparse_jacobian.xml#Method',
'link_sparse_jacobian.xml#size',
'link_sparse_jacobian.xml#repeat',
'link_sparse_jacobian.xml#m',
'link_sparse_jacobian.xml#x',
'link_sparse_jacobian.xml#row',
'link_sparse_jacobian.xml#col',
'link_sparse_jacobian.xml#jacobian',
'link_sparse_jacobian.xml#jacobian.double'
];
function choose_across0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_across0[index-1];
}
function choose_up0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_up0[index-1];
}
function choose_down3(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down3[index-1];
}
function choose_down2(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down2[index-1];
}
function choose_down1(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down1[index-1];
}
function choose_down0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down0[index-1];
}
function choose_current0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_current0[index-1];
}

==> cppad_2015.00.00.9.orig.tar.gz: cppad-20150000.9/doc/_link_sparse_jacobian_xml.js <==
var list_across0 = [
'_contents_xml.htm',
'_reference.xml',
'_index.xml',
'_search_xml.htm',
'_external.xml'
];
var list_up0 = [
'cppad.xml',
'speed.xml',
'speed_main.xml',
'link_sparse_jacobian.xml'
];
var list_down3 = [
'install.xml',
'introduction.xml',
'ad.xml',
'adfun.xml',
'preprocessor.xml',
'multi_thread.xml',
'library.xml',
'ipopt_solve.xml',
'example.xml',
'speed.xml',
'appendix.xml'
];
var list_down2 = [
'speed_main.xml',
'speed_utility.xml',
'speed_double.xml',
'speed_adolc.xml',
'speed_cppad.xml',
'speed_fadbad.xml',
'speed_sacado.xml'
];
var list_down1 = [
'link_det_lu.xml',
'link_det_minor.xml',
'link_mat_mul.xml',
'link_ode.xml',
'link_poly.xml',
'link_sparse_hessian.xml',
'link_sparse_jacobian.xml',
'microsoft_timer.xml'
];
var list_current0 = [
'link_sparse_jacobian.xml#Prototype',
'link_sparse_jacobian.xml#Method',
'link_sparse_jacobian.xml#size',
'link_sparse_jacobian.xml#repeat',
'link_sparse_jacobian.xml#m',
'link_sparse_jacobian.xml#row',
'link_sparse_jacobian.xml#col',
'link_sparse_jacobian.xml#x',
'link_sparse_jacobian.xml#jacobian',
'link_sparse_jacobian.xml#n_sweep',
'link_sparse_jacobian.xml#n_sweep.double'
];
function choose_across0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_across0[index-1];
}
function choose_up0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_up0[index-1];
}
function choose_down3(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down3[index-1];
}
function choose_down2(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down2[index-1];
}
function choose_down1(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down1[index-1];
}
function choose_down0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down0[index-1];
}
function choose_current0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_current0[index-1];
}
